import React from "react";
import { Link } from "react-router-dom";
import classNames from "classnames";
import { format } from "date-fns";

import Chip from "components/Chip";
import { ProgramStore } from "stores";

const Schedule = () => {
  const { current, schedule } = ProgramStore.useState();
  return (
    <article className="container container--wide py-8 lg:py-24">
      <h1 className="head-alt-md lg:head-alt-lg mb-8">Program zasedání</h1>
      <div className="flex flex-col">
        {schedule.map((entry) => {
          const isCurrent = entry === current;
          return (
            <div
              className={classNames(
                "flex flex-col md:flex-row my-4 hover:opacity-100 transition duration-300",
                {
                  "text-black": isCurrent,
                  "text-black opacity-50": !isCurrent,
                }
              )}
              key={entry.id}
            >
              <div className="w-28 md:text-right">
                {isCurrent && (
                  <Chip condensed className="mt-2 mr-2" color="red-600">
                    Právě probíhá
                  </Chip>
                )}
              </div>
              <div className="w-32 flex items-start head-heavy-xs md:head-heavy-base text-center">
                <span>{format(entry.expectedStartAt, "H:mm")}</span>
              </div>
              <div className="flex-grow w-full">
                <h2 className="head-heavy-xs md:head-heavy-base mb-1">
                  <Link to="/">{entry.title}</Link>
                </h2>
                <div className="flex space-x-2">
                  <strong>Navrhovatel:</strong>
                  <span>{entry.proposer}</span>
                </div>
                {entry.description && <p>{entry.description}</p>}
              </div>
            </div>
          );
        })}
      </div>
    </article>
  );
};

export default Schedule;
